import expressValidator from 'express-validator';
import express from 'express';
import cookieParser from 'cookie-parser';
import compression from 'compression';
import cors from 'cors';
import { resolve } from 'path';

import router from './router';

import { middlewareRequestLogger, expressErrorLogger } from './lib/logger';

const app = express();

app.enable('trust proxy');


// global middlewares go here
app.use(cookieParser());
app.use(middlewareRequestLogger);

app.use(expressValidator());

app.use(compression());

// app.disable('x-powered-by');

app.use(express.static(resolve(__dirname, './public'), { maxAge: 31557600000 }));

app.use(cors({
  origin: '*',
  credentials: true,
  // exposedHeaders: ['X-Count', 'X-Items-Per-Page', 'X-Page'],
  allowedHeaders: ['Origin', 'X-HTTP-Method-Override', 'X-Requested-With', 'Content-Type', 'Accept', 'Authorization', 'pragma', 'cache-control']
}));


app.use(router);

expressErrorLogger(app);


export default app;
