import parseBearerToken from 'parse-bearer-token';
import { isUUID } from 'validator';
import { InvalidRequestError, UnauthorizedError } from '../errors';

/**
 * @param {string} role
 */
export default ({ role = null } = {}) => async (req, res, next) => {
  const { db } = req;
  const {Op} = db.Sequelize;
  const token = parseBearerToken(req);

  if (!token || !isUUID(token)) {
    return next(new InvalidRequestError('Token is invalid'));
  }

  try {
    const session = await db.session.findOne({
      attributes: ['id', 'token', 'expires', 'createdAt'],
      where: {
        token,
        expires: {
          [Op.gt]: Date.now(),
        },
      },
      include: [{
        model: db.user,
        required: true,
        attributes: db.user.attrs,
      }],
    });

    if (!session) {
      return next(new UnauthorizedError('Session not found'));
    }

    const {user} = session;
    user.session = session;

    if (role && user.role !== role) {
      throw new UnauthorizedError('Access denied');
    }

    req.user = user;
    req.session = session;

    await user.session.live({ clientIP: req.clientIP });

    return next();
  } catch (error) {
    return next(error);
  }
};
