import fs from 'fs';
import path from 'path';
import { AppError } from '../../errors';


const templates = {
  activationLetter: {
    name: 'activationLetter',
    path: path.resolve(__dirname, './activationLetter.html'),
    subject: () => 'Hi, confirm your email.',
    params: ['FULLNAME', 'USEREMAIL', 'CONFIRMLINK'],
  },
  subscriptionStarted: {
    name: 'subscriptionStarted',
    path: path.resolve(__dirname, './subscriptionStarted.html'),
    subject: () => 'Enjoy Ench.app Premium / Receipt',
    params: [
      'USERID',
      'FULLNAME',
      'USEREMAIL',
      'ORDERID',
      'DATE',
      'PERIOD',
      'PRICE',
      'PAYMENTMETHOD',
    ],
  },
  newPasswordRequest: {
    name: 'newPasswordRequest',
    path: path.resolve(__dirname, './newPasswordRequest.html'),
    params: ['FULLNAME', 'LINK'],
    subject: () => 'Forgot your password, huh?',
  },
  passwordChanged: {
    name: 'passwordChanged',
    path: path.resolve(__dirname, './passwordChanged.html'),
    subject: () => 'Your password was changed.',
    params: ['FULLNAME'],
  },
  paymentFailed: {
    name: 'paymentFailed',
    path: path.resolve(__dirname, './paymentFailed.html'),
    subject: () => 'Payment failed!',
    params: [],
  },
  newDashboardUser: {
    name: 'newDashboardUser',
    path: path.resolve(__dirname, './newDashboardUser.html'),
    subject: () => 'New user at @ench/dashboard',
    params: ['currentUser', 'newUser', 'role'],
  }
};

Object.keys(templates).forEach((key) => {
  const template = templates[key];
  if (!fs.existsSync(template.path)) {
    throw new AppError('Template not found');
  }

  template.html = fs.readFileSync(template.path, 'utf8').toString();
});

export default templates;
