/**
  @apiDefine InternalError
  @apiError (Error 500) InternalError
  @apiGroup 5xx
  */
export class AppError extends Error {
  constructor(error) {
    super(error);

    this.success = false;
    this.soft = false;

    this.error = error;
    if (!error) {
      this.message = 'Internal error';
    } else {
      this.message = error.message ? error.message : error;
    }
  }

  statusCode = 500;
}


// soft error doesn't log to a server
/**
  @apiDefine SoftError
  @apiError (Error 400) SoftError
  @apiGroup 4xx
  */
export class SoftError extends AppError {
  constructor(input) {
    super(input);
    this.statusCode = 400;
    this.soft = true;
  }
}


// some general errors
/**
  @apiDefine InvalidRequestError
  @apiError (Error 400) InvalidRequestError
  @apiGroup 4xx
  */
export class InvalidRequestError extends SoftError {
}

/**
  @apiDefine AlreadyRegisteredError
  @apiError (Error 409) AlreadyRegisteredError
  @apiGroup 4xx
  */
export class AlreadyRegisteredError extends SoftError {
  constructor(input) {
    super(input || 'Already registered');
    this.statusCode = 409;
  }
}

/**
  @apiDefine UnauthorizedError
  @apiError (Error 401) UnauthorizedError
  @apiGroup 4xx
  */
export class UnauthorizedError extends SoftError {
  constructor(input) {
    super(input);
    this.statusCode = 401;
  }
}

/**
  @apiDefine ForbiddenError
  @apiError (Error 403) ForbiddenError
  @apiGroup 4xx
  */
export class ForbiddenError extends SoftError {
  constructor(input) {
    super(input);
    this.statusCode = 403;
  }
}

/**
  @apiDefine NotFoundError
  @apiError (Error 404) NotFoundError
  @apiGroup 4xx
  */
export class NotFoundError extends SoftError {
  constructor(message) {
    super(message);
    this.statusCode = 404;
  }
}

/**
  @apiDefine NotAcceptableError
  @apiError (Error 406) NotAcceptableError
  @apiGroup 4xx
  */
export class NotAcceptableError extends SoftError {
  constructor(message) {
    super(message);
    this.statusCode = 406;
  }
}

/**
  @apiDefine FailedValidationError
  @apiError (Error 400) FailedValidationError
  @apiGroup 4xx
  */
export class FailedValidationError extends InvalidRequestError {
  constructor(input) {
    super(input);
    this.statusCode = 400;
  }
}

/**
  @apiDefine AlreadyAcceptedError
  @apiError (Error 208) AlreadyAcceptedError
  @apiGroup 2xx
  */
export class AlreadyAcceptedError extends InvalidRequestError {
  constructor(input) {
    super(input);
    this.statusCode = 208;
  }
}
