import winston from 'winston';

// eslint-disable-next-line no-unused-expressions
require('winston-papertrail').Papertraill;


const createLogger = (label = 'stdout') => {
  const opts = {
    transports: [
      new winston.transports.Console({
        colorize: 'level',
        timestamp: true,
        // json: true,
      }),
    ],
  };

  // if (['production', 'staging'].indexOf(process.env.NODE_ENV) !== -1) {
  //   opts.transports.push(
  //     new winston.transports.Papertrail({
  //       host: 'logs5.papertrailapp.com',
  //       port: 52629,
  //       timestamp: true,
  //       colorize: true,
  //       handleExceptions: true,
  //     })
  //   );
  // }

  const winstonLogger = new winston.Logger(opts);

  winstonLogger.on('error', (err) => {
    console.error(err);
  });

  // LEVELS
  // log -> info
  // info
  // warn
  // error


  const logger = {
    label,
    log: (...args) => {
      winstonLogger.log('info', `[${label}]`, ...args);
    },
    info: (...args) => {
      winstonLogger.log('info', `[${label}]`, ...args);
    },
    warn: (...args) => {
      winstonLogger.log('warn', `[${label}]`, ...args);
    },
    error: (...args) => {
      winstonLogger.log('error', `[${label}]`, ...args);
    },
  };

  return logger;
};

// main stdout logger
const logger = createLogger();


export const sqlLogger = createLogger('sql');

export const matomoLogger = createLogger('matomo');

export const braintreeLogger = createLogger('braintree');


const requestLogger = createLogger('request');
export const middlewareRequestLogger = async (req, res, next) => {
  // don't litter in logs
  if (req.url === '/health_check') {
    return next();
  }

  const start = Date.now();
  await next();
  requestLogger.info(`${req.method} ${req.url} ${res.statusCode} - ${Date.now() - start}ms`);
};

export const expressErrorLogger = (app) => {
  const expressLogger = createLogger();

  app.use((err, req, res, next) => {
    expressLogger.error(err);
    // if (err instanceof SoftError) {
    return next(err);
    // }
  });
};

export default logger;
