import moment from 'moment';

module.exports = (sequelize, DataTypes) => {
  const Model = sequelize.define('appointment', {
    id: {
      type: DataTypes.INTEGER,
      allowNull: false,
      primaryKey: true,
      autoIncrement: true,
    },
    authorId: {
      type: DataTypes.INTEGER,
      allowNull: false,
      references: {
        model: 'user',
        key: 'id',
      },
    },
    doctorId: {
      type: DataTypes.INTEGER,
      allowNull: false,
      references: {
        model: 'user',
        key: 'id',
      },
    },
    clientId: {
      type: DataTypes.INTEGER,
      allowNull: false,
      references: {
        model: 'client',
        key: 'id',
      },
    },
    cabinetId: {
      type: DataTypes.INTEGER,
      allowNull: false,
      references: {
        model: 'cabinet',
        key: 'id',
      },
    },
    visitDate: {
      type: DataTypes.DATEONLY,
      allowNull: false,
    },
    visitTimeFrom: {
      type: DataTypes.DATE,
      allowNull: false,
    },
    // sessionTimeTo + 30 min
    visitTimeTo: {
      type: DataTypes.DATE,
      allowNull: false,
    },
    sessionTimeTo: {
      type: DataTypes.DATE,
      allowNull: false,
    },
    complaint: {
      type: DataTypes.STRING(1000),
      allowNull: true,
    },
    diagnosis: {
      type: DataTypes.STRING(1000),
      allowNull: true,
    },
    comment: {
      type: DataTypes.STRING(1000),
      allowNull: true,
    },
    clientNotifiedAt: {
      type: DataTypes.DATE,
      allowNull: true,
    },
  }, {
    tableName: 'appointment',
    timestamps: true,
    paranoid: true,
  });

  Model.attrs = [
    'id',
    'authorId',
    'doctorId',
    'clientId',
    'cabinetId',
    'visitDate',
    'visitTimeFrom',
    'visitTimeTo',
    'sessionTimeTo',
    'complaint',
    'diagnosis',
    'comment',
    'clientNotifiedAt',
  ];

  Model.fetch = function fetch({ db, id }) {
    return db.appointment.findOne({
      attributes: Model.attrs,
      where: { id },
      include: [{
        model: db.user,
        required: true,
        as: 'doctor',
      }, {
        model: db.client,
        required: true,
      }, {
        model: db.cabinet,
        required: true,
      }, {
        model: db.user,
        required: true,
        as: 'author',
      }],
    });
  };

  Model.prototype.format = function format() {
    return {
      id: this.id,
      visitDate: moment(this.visitDate).format('DD-MM-YYYY'),
      visitTimeFrom: moment(this.visitTimeFrom).format('HH:mm'),
      visitTimeTo: moment(this.visitTimeTo).format('HH:mm'),
      sessionTimeTo: moment(this.sessionTimeTo).format('HH:mm'),
      complaint: this.complaint,
      diagnosis: this.diagnosis,
      comment: this.comment,
      clientNotifiedAt: !!this.clientNotifiedAt,
      author: this.author.format(),
      cabinet: this.cabinet.format(),
      client: this.client.format(),
      doctor: this.doctor.format(),
    };
  };

  return Model;
};
