module.exports = (sequelize, DataTypes) => {
  const Model = sequelize.define('requestedScheduleUpdates', {
    id: {
      type: DataTypes.INTEGER,
      allowNull: false,
      primaryKey: true,
      autoIncrement: true,
    },
    doctorId: {
      type: DataTypes.INTEGER,
      allowNull: false,
      references: {
        model: 'user',
        key: 'id',
      },
    },
    day: {
      type: DataTypes.ENUM('monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday'),
      allowNull: false,
    },
    // time only HH:mm:ss
    from: {
      type: DataTypes.STRING(10),
      allowNull: false,
    },
    // time only HH:mm:ss
    to: {
      type: DataTypes.STRING(10),
      allowNull: false,
    },
  }, {
    tableName: 'requestedScheduleUpdates',
    timestamps: true,
    updatedAt: false,
    paranoid: false,
  });

  Model.days = [
    'sunday',
    'monday',
    'tuesday',
    'wednesday',
    'thursday',
    'friday',
    'saturday',
  ];

  Model.getSchedule = async function getSchedule({ db, doctorId = null } = {}) {
    const rows = await db.requestedScheduleUpdates.findAll({
      where: {
        doctorId,
      },
    });

    if (rows.length === 0) {
      return null;
    }

    return rows.reduce((obj, row) => {
      const { day } = row;
      if (!obj[day]) {
        obj[day] = {
          from: null,
          to: null,
        };
      }

      obj[day].from = row.from;
      obj[day].to = row.to;

      return obj;
    }, {});
  };


  return Model;
};
