import moment from 'moment';
import config from '../config';

const lifetime = config.auth.expiresDays;

module.exports = (sequelize, DataTypes) => {
  const Session = sequelize.define('session', {
    id: {
      type: DataTypes.INTEGER,
      allowNull: false,
      primaryKey: true,
      autoIncrement: true,
    },
    userId: {
      type: DataTypes.INTEGER,
      allowNull: false,
      references: {
        model: 'user',
        key: 'id',
      },
    },
    token: {
      type: DataTypes.UUID,
      defaultValue: DataTypes.UUIDV4,
      allowNull: false,
    },
    expires: {
      type: DataTypes.DATE,
      allowNull: true,
    },
    clientIP: {
      type: DataTypes.STRING,
      allowNull: true,
    },
    country: {
      type: DataTypes.STRING,
      allowNull: true,
    },
    location: {
      type: DataTypes.JSONB,
      allowNull: true,
    },
  }, {
    tableName: 'session',
    timestamps: true,
    paranoid: false,
  });

  // set the expires date of session
  Session.addHook('beforeCreate', (session) => {
    session.expires = moment().add(lifetime, 'd');
  });

  // update the expires date of session
  Session.prototype.live = function live({ clientIP = null }) {
    const up = {
      expires: moment().add(lifetime, 'd')
    };
    if (clientIP) {
      up.clientIP = clientIP;
    }
    return this.update(up);
  };

  return Session;
};
