import logger from '../../../lib/logger';

/**
  @api {delete} /account Delete user
  @apiGroup Account
  @apiDescription Delete user

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "success": true
    }

  @apiUse UnauthorizedError
  @apiUse InternalError
*/
export default async (req, res, next) => {
  const {
    db,
    user,
  } = req;

  try {
    await db.sequelize.transaction(async (transaction) => {
      await db.session.destroy({
        where: { userId: user.id },
        transaction,
      });

      await db.schedule.destroy({
        where: { userId: user.id },
        transaction,
      });

      await user.destroy({
        transaction,
      });
    });

    return res.send({
      success: true,
    });
  } catch (err) {
    logger.error(err);
    next(err);
  }
};
