import { NotFoundError, UnauthorizedError } from '../../../lib/errors';

/**
  @api {delete} /appointment/:id Archive
  @apiGroup Appointment

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "success": true
    }

  @apiUse UnauthorizedError
  @apiUse InternalError
*/
export default async (req, res, next) => {
  const { db, user } = req;
  const { id } = req.params;

  try {
    if (['director', 'administrator'].indexOf(user.role) === -1) {
      throw new UnauthorizedError('Access denied');
    }

    const appointment = await db.appointment.fetch({ db, id });
    if (!appointment) {
      throw new NotFoundError('Appointment not found');
    }

    await appointment.destroy();

    res.send({
      success: true,
    });
  } catch (err) {
    return next(err);
  }
};
