/**
  @api {get} /appointment/:id Get info
  @apiGroup Appointment

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "id": 19,
      "visitDate": "25-11-2020",
      "visitTimeFrom": "15:00",
      "visitTimeTo": "16:30",
      "sessionTimeTo": "16:00",
      "complaint": "complaint complaint complaint",
      "diagnosis": "diagnosis diagnosis",
      "comment": "comment",
      "clientNotifiedAt": false,
      "author": {
          "id": 1,
          "email": "director@company.com",
          "role": "director",
          "firstName": "A",
          "lastName": "",
          "photoUrl": null,
          "doctorSpecialization": null,
          "isDoctor": true,
          "colorCode": "#000000"
      },
      "cabinet": {
          "id": 1,
          "title": "A",
          "colorCode": "#151231"
      },
      "client": {
          "id": 4,
          "firstName": "firstName",
          "lastName": "lastName",
          "birthDate": "15-02-1951",
          "birthNumber": "1234123",
          "insuranceNumber": "6662341",
          "street": "street",
          "city": "city",
          "postcode": "123122",
          "allergies": "allergies",
          "notificationType": "sms"
      },
      "doctor": {
          "id": 1,
          "email": "director@company.com",
          "role": "director",
          "firstName": "A",
          "lastName": "",
          "photoUrl": null,
          "doctorSpecialization": null,
          "isDoctor": true,
          "colorCode": "#000000"
      }
    }

  @apiUse InternalError
  @apiUse UnauthorizedError
*/
export default async (req, res) => {
  const { db } = req;
  const { id } = req.params;
  const row = await db.appointment.fetch({ db, id });
  const response = row.format();

  res.send(response);
};
