import moment from 'moment';

import { NotFoundError, InvalidRequestError, AlreadyAcceptedError } from '../../../lib/errors';

/**
 * @param {Object} body
 */
export async function upsertClient({
  db,
  body,
  user,
  transaction,
}) {
  const { Op } = db.Sequelize;
  let client = null;
  const up = [
    'firstName',
    'lastName',
    'birthNumber',
    'insuranceNumber',
    'street',
    'city',
    'postcode',
    'allergies',
    'notificationType',
  ].reduce((obj, key) => {
    if (body[key]) {
      obj[key] = body[key];
    }
    return obj;
  }, {});

  if (body.birthDate) {
    const birthDate = moment(body.birthDate, 'DD-MM-YYYY');
    if (!birthDate.isValid()) {
      throw new InvalidRequestError('Birth date is invalid');
    }

    up.birthDate = birthDate.toDate();
  }


  // update
  if (body.id) {
    client = await db.client.findOne({
      where: { id: body.id },
      transaction,
    });
    if (!client) {
      throw new NotFoundError('Client not found');
    }

    return client.update(up, { transaction });
  }

  // create
  {
    const dup = await db.client.findOne({
      attributes: ['id', 'birthNumber', 'insuranceNumber'],
      where: {
        [Op.or]: [{
          birthNumber: body.birthNumber,
        }, {
          insuranceNumber: body.insuranceNumber,
        }],
      },
      transaction,
    });
    if (dup) {
      throw new AlreadyAcceptedError(`Client already exists (id #${dup.id}, birth number #${dup.birthNumber}, insurance number #${dup.insuranceNumber})`);
    }
  }

  up.authorId = user.id;
  return db.client.create(up, { transaction });
}

export default {
  upsertClient,
};
