import { NotFoundError } from '../../../lib/errors';

/**
  @api {delete} /auth/:id Archive
  @apiGroup Auth
  @apiDescription Delete user

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "success": true
    }

  @apiUse InternalError
  @apiUse UnauthorizedError
*/
export default async (req, res, next) => {
  const { db } = req;
  const { id } = req.params;

  try {
    const user = await db.user.findOne({
      where: { id },
    });

    if (!user) {
      throw new NotFoundError('User not found');
    }

    await db.session.destroy({
      where: { userId: user.id },
    });

    await user.destroy();

    res.send({ success: true });
  } catch (err) {
    return next(err);
  }
};
