import {has} from 'lodash';
import { InvalidRequestError } from '../../../lib/errors';

/**
  @api {post} /cabinet Create cabinet
  @apiGroup Cabinet

  @apiHeader {string} Authorization Bearer ${token}

  @apiParam {string} title
  @apiParam {string} [colorCode]

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "id": 5,
      "title": "A",
      "colorCode": null
    }

  @apiUse InternalError
  @apiUse UnauthorizedError
  @apiUse InvalidRequestError
*/
export default async (req, res, next) => {
  const { db } = req;

  req.checkBody({
    title: {
      notEmpty: true,
      errorMessage: 'Title is required',
    },
    colorCode: {
      optional: true,
    },
  });

  try {
    const errs = await req.getValidationResult();
    if (!errs.isEmpty()) {
      throw new InvalidRequestError(errs.array());
    }

    const toCreate = {
      title: req.body.title,
    };

    if (has(req.body, 'colorCode')) {
      toCreate.colorCode = req.body.colorCode;
    }

    const cabinet = await db.cabinet.create(toCreate);

    const response = cabinet.format();

    return res.json(response);
  } catch (err) {
    next(err);
  }
};
