import { has } from 'lodash';

/**
  @api {get} /client Search client
  @apiGroup Client

  @apiHeader {string} Authorization Bearer ${token}

  @apiParam {string} [firstName] [query param]
  @apiParam {string} [lastName] [query param]
  @apiParam {string} [birthNumber] [query param]
  @apiParam {string} [insuranceNumber] [query param]

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "id": 5,
      "role": "doctor",
      "email": "user@test.com",
      "firstName": "Name",
      "lastName": "Last",
      "photoUrl": "",
      "doctorSpecialization": ""
    }

  @apiUse InternalError
  @apiUse UnauthorizedError
*/
export default async (req, res) => {
  const { db } = req;
  const { Op } = db.Sequelize;
  const where = {};

  if (has(req.query, 'firstName') && has(req.query, 'lastName')) {
    where.firstName = {
      [Op.iLike]: `%${req.query.firstName}%`,
    };
    where.lastName = {
      [Op.iLike]: `%${req.query.lastName}%`,
    };
  }

  if (has(req.query, 'birthNumber')) {
    where.birthNumber = {
      [Op.iLike]: `%${req.query.birthNumber}%`,
    };
  }

  if (has(req.query, 'insuranceNumber')) {
    where.insuranceNumber = {
      [Op.iLike]: `%${req.query.insuranceNumber}%`,
    };
  }

  if (Object.keys(where).length === 0) {
    return res.send({
      success: false,
    });
  }

  const client = await db.client.findOne({
    attributes: db.client.attrs,
    where,
  });

  if (!client) {
    return res.send({
      success: false,
    });
  }

  const response = {
    success: true,
    client: client.format(),
  };

  res.send(response);
};
