import { NotFoundError } from '../../../lib/errors';

/**
  @api {post} /requestedScheduleUpdates/approve/:userId Approve request
  @apiGroup Requested Schedule

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "success": true
    }

  @apiUse InternalError
  @apiUse UnauthorizedError
*/
export default async (req, res, next) => {
  const { db, user: currentUser } = req;
  const { userId } = req.params;

  try {
    const user = await db.user.findOne({
      attributes: ['id'],
      where: { id: userId },
    });

    if (!user) {
      throw new NotFoundError('User not found');
    }

    const schedule = await db.requestedScheduleUpdates.getSchedule({ db, doctorId: user.id });
    if (!schedule) {
      throw new NotFoundError('Schedule not found');
    }


    await db.sequelize.transaction(async (transaction) => {
      await Promise.each(db.requestedScheduleUpdates.days, async (day) => {
        const row = await db.schedule.findOne({
          where: {
            userId: user.id,
            day,
          },
          transaction,
        });

        if (!row) {
          return db.schedule.create({
            userId: user.id,
            day,
            from: schedule[day].from,
            to: schedule[day].to,
            lastEditBy: currentUser.id,
          }, { transaction });
        }
        return row.update({
          from: schedule[day].from,
          to: schedule[day].to,
          lastEditBy: currentUser.id,
        }, { transaction });
      });
    });

    res.send({ success: true });
  } catch (err) {
    return next(err);
  }
};
