import { NotFoundError } from '../../../lib/errors';

/**
  @api {post} /requestedScheduleUpdates/decline/:userId Decline request
  @apiGroup Requested Schedule

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "success": true
    }

  @apiUse InternalError
  @apiUse UnauthorizedError
*/
export default async (req, res, next) => {
  const { db } = req;
  const { userId } = req.params;

  try {
    const user = await db.user.findOne({
      attributes: ['id'],
      where: { id: userId },
    });

    if (!user) {
      throw new NotFoundError('User not found');
    }

    const schedule = await db.requestedScheduleUpdates.getSchedule({ db, doctorId: user.id });
    if (!schedule) {
      throw new NotFoundError('Schedule not found');
    }

    await db.requestedScheduleUpdates.destroy({
      where: { doctorId: user.id },
    });

    res.send({ success: true });
  } catch (err) {
    return next(err);
  }
};
