/**
  @api {get} /requestedScheduleUpdates List
  @apiGroup Requested Schedule

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    [{
      "doctor": {
        "id": 123,
        "email": "username@email.com",
        "role": "director",
        "firstName": "John",
        "lastName": "Doe",
        "photoUrl": "",
        "doctorSpecialization": "",
        "colorCode": "",
        "isDoctor": true
      },
      "schedule": {
        "monday": {
          "from": "10:00",
          "to": "16:00"
        },
        "tuesday": {
          "from": "10:00",
          "to": "16:00"
        },
        "wednesday": {
          "from": "10:00",
          "to": "16:00"
        },
        "thursday": {
          "from": "10:00",
          "to": "16:00"
        },
        "friday": {
          "from": "10:00",
          "to": "16:00"
        },
        "saturday": {
          "from": "10:00",
          "to": "16:00"
        },
        "sunday": {
          "from": "10:00",
          "to": "16:00"
        }
      }
    }]

  @apiUse InternalError
  @apiUse UnauthorizedError
*/
export default async (req, res, next) => {
  const { db } = req;

  try {
    const doctors = await db.user.findAll({
      where: { isDoctor: true },
    });

    const response = await Promise.reduce(doctors, async (arr, doctor) => {
      const schedule = await db.requestedScheduleUpdates.getSchedule({ db, doctorId: doctor.id });

      if (schedule) {
        arr.push({
          doctor: doctor.format(),
          schedule,
        });
      }

      return arr;
    }, []);

    res.send(response);
  } catch (err) {
    return next(err);
  }
};
