import { NotFoundError } from '../../../lib/errors';

/**
  @api {get} /schedule/general Get general schedule
  @apiGroup Schedule

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "monday": {
        "from": "10:00",
        "to": "16:00"
      },
      "tuesday": {
        "from": "10:00",
        "to": "16:00"
      },
      "wednesday": {
        "from": "10:00",
        "to": "16:00"
      },
      "thursday": {
        "from": "10:00",
        "to": "16:00"
      },
      "friday": {
        "from": "10:00",
        "to": "16:00"
      },
      "saturday": {
        "from": "10:00",
        "to": "16:00"
      },
      "sunday": {
        "from": "10:00",
        "to": "16:00"
      }
    }

  @apiUse InternalError
  @apiUse UnauthorizedError
*/
export default async (req, res, next) => {
  const { db } = req;

  try {
    const response = await db.schedule.getSchedule({ db, userId: null });

    if (!response) {
      throw new NotFoundError('Schedule is not set');
    }

    res.send(response);
  } catch (err) {
    return next(err);
  }
};
