import { NotFoundError } from '../../../lib/errors';

/**
  @api {get} /schedule/:userId Get user schedule
  @apiGroup Schedule

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    {
      "monday": {
        "from": "10:00",
        "to": "16:00"
      },
      "tuesday": {
        "from": "10:00",
        "to": "16:00"
      },
      "wednesday": {
        "from": "10:00",
        "to": "16:00"
      },
      "thursday": {
        "from": "10:00",
        "to": "16:00"
      },
      "friday": {
        "from": "10:00",
        "to": "16:00"
      },
      "saturday": {
        "from": "10:00",
        "to": "16:00"
      },
      "sunday": {
        "from": "10:00",
        "to": "16:00"
      }
    }

  @apiUse InternalError
  @apiUse UnauthorizedError
*/
export default async (req, res, next) => {
  const { db } = req;
  const { userId } = req.params;

  try {
    const user = await db.user.findOne({
      attributes: ['id'],
      where: { id: userId },
    });

    if (!user) {
      throw new NotFoundError('User not found');
    }

    const response = await db.schedule.getSchedule({ db, userId: user.id });

    if (!response) {
      throw new NotFoundError('Schedule is not set');
    }

    res.send(response);
  } catch (err) {
    return next(err);
  }
};
