/**
  @api {get} /user/doctors Doctor list
  @apiGroup User

  @apiHeader {string} Authorization Bearer ${token}

  @apiSuccessExample {json} Success
    HTTP/1.1 200 OK
    [{
      "id": 5,
      "role": "doctor",
      "email": "user@test.com",
      "firstName": "Name",
      "lastName": "Last",
      "photoUrl": "",
      "doctorSpecialization": "",
      "colorCode": "",
      "isDoctor": true
    }]

  @apiUse InternalError
  @apiUse UnauthorizedError
*/
export default async (req, res) => {
  const { db } = req;
  const { Op } = db.Sequelize;
  const users = await db.user.findAll({
    where: {
      role: {
        [Op.in]: ['director', 'doctor'],
      }
    },
  });

  const doctors = users.map(user => user.format());

  res.send(doctors);
};
