import { Router } from 'express';

import logger from '../lib/logger';

import api from './api';

const db = require('../models')();

const router = Router();

/**
 * Set db connection to the req context
 * and get the clear client IP
 */
router.use((req, res, next) => {
  req.db = db;

  const ip = req.headers['x-forwarded-for'] || req.connection.remoteAddress || '';
  req.clientIP = ip.replace('::ffff:', '');

  return next();
});

router.get('/health_check', (req, res) => res.sendStatus(204));


router.use('/v1', api);


/**
 * Handle unknown routes
 */
router.use('*', (req, res) => res.sendStatus(404));


/**
 * Error Handler
 */
// eslint-disable-next-line no-unused-vars
router.use((error, req, res, next) => {
  let err = error;

  logger.error(error);

  if (!Object.prototype.hasOwnProperty.call(error, 'statusCode')) {
    err = {
      success: false,
      statusCode: 500,
      message: 'Internal error',
    };

    if (process.env.NODE_ENV === 'production') {
      err.message = error.message;
    }

    if (process.env.NODE_ENV === 'staging') {
      err.message = error.message;
      err.stack = error.stack;
    }
  }

  return res.status(err.statusCode).json(err);
});


export default router;
