global.Promise = require('bluebird');
require('dotenv').config();

let appPath = './build';

if (['production', 'staging'].indexOf(process.env.NODE_ENV) === -1) {
  appPath = './app';
  global.Promise.config({
    // Enable warnings
    warnings: true,
    // Enable long stack traces
    longStackTraces: false,
    // Enable cancellation
    cancellation: true,
    // Enable monitoring
    monitoring: false
  });
  require('babel-core/register')();
}
require('babel-runtime/core-js/promise').default = global.Promise;

const config = require(`${appPath}/config`);
const app = require(appPath); // execute
const server = require('http').Server(app);

const logger = require(`${appPath}/lib/logger`).default;


// create server
server.listen(config.server.port, (error) => {
  if (error) {
    logger.error('Unable to listen for connections', error);
    process.exit(10);
  }
  logger.info(`Express server is listening on port: ${config.server.port}`);
});
