import React, { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { Switch, Route, Redirect } from 'react-router-dom';
import { selectIsUserAuth } from './reducers/userReducer';
import { LoginPage } from './screens/LoginPage';
import { MainPage } from './screens/MainPage';
import { SettingsPage } from './screens/SettingsPage';
import { request } from './utils/api';
import { deleteCookie, getCookie } from './utils/cookies';

export const Router = () => {
  const dispatch = useDispatch();
  const isAuth = useSelector(selectIsUserAuth);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    setLoading(true);
    const token = getCookie('token');
    request({
      url: 'http://45.137.148.94/v1/auth/ping',
      method: 'GET',
      headers: {
        Authorization: `Bearer ${token}`,
      },
    })
      .then(({ success, user }) => {
        if (success) {
          dispatch({ type: 'auth', payload: { user } });
          setLoading(false);
        }
      })
      .catch(() => {
        console.log('deleting');
        deleteCookie('token');
        setLoading(false);
      });
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  if (loading) {
    return null;
  }

  return (
    <Switch>
      <Route path="/login" exact render={() => (isAuth ? <Redirect to="/" /> : <LoginPage />)} />
      <Route
        path="/settings"
        exact
        render={() => (!isAuth ? <Redirect to="/login" /> : <SettingsPage />)}
      />
      <Route path="/" exact render={() => (!isAuth ? <Redirect to="/login" /> : <MainPage />)} />
    </Switch>
  );
};
