import React, { useEffect, useState } from 'react';
import { ViewState, GroupingState, IntegratedGrouping } from '@devexpress/dx-react-scheduler';
import {
  Scheduler,
  Resources,
  Appointments,
  GroupingPanel,
  DayView,
} from '@devexpress/dx-react-scheduler-material-ui';
import { Grid, makeStyles } from '@material-ui/core';
import { Appointment } from './components/Appointment';
import { fakeAppointments, fakeCabinets } from '../../mocks';
import { request } from '../../utils/api';
import { getCookie } from '../../utils/cookies';

const translateAppointments = (apps = []) =>
  apps.map((appointment) => {
    const [day, month, year] = appointment.visitDate.split('-');
    const [hourFrom, minFrom] = appointment.visitTimeFrom.split(':');
    const [hourTo, minTo] = appointment.visitTimeTo.split(':');

    return {
      id: appointment.id,
      startDate: new Date(year, month - 1, day, hourFrom, minFrom),
      endDate: new Date(year, month - 1, day, hourTo, minTo),
      cabinetId: appointment.cabinet.id,
      doctorId: appointment.doctor.id,
      doctor: `${appointment.doctor.firstName} ${appointment.doctor.lastName}`,
      patient: `${appointment.client.firstName} ${appointment.client.lastName}`,
      color: appointment.doctor.colorCode,
    };
  });

const appointments = translateAppointments([fakeAppointments[0]]);

const useStyles = makeStyles(() => ({
  container: {
    height: '100%',
    overflow: 'auto',
    background: '#383972',
    '& > div > div > div > div > div, & > div > div > div > div > div > div': {
      background: '#383972',
      color: '#ffffff !important',
    },
    '& .MuiTableCell-body > div > *': {
      color: '#ffffff !important',
    },
    '& .makeStyles-stickyElement-31': {
      backgroundColor: 'transparent',
    },
    '& .makeStyles-background-42': {
      backgroundColor: 'transparent',
    },
  },
}));

const weekDays = ['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday'];

export const DayScheduler = ({ date, selectedPerson }) => {
  const classes = useStyles();
  const [data, setData] = useState(appointments);
  const [dayTime, setDayTime] = useState({ from: 7, to: 10 });
  const [resources, setResources] = useState([
    {
      fieldName: 'cabinetId',
      title: 'Location',
      instances: fakeCabinets.map((cab) => ({
        ...cab,
        text: cab.title,
        color: cab.colorCode,
      })),
    },
  ]);
  const [grouping] = useState([
    {
      resourceName: 'cabinetId',
    },
  ]);

  const [loading, setLoading] = useState(true);

  useEffect(() => {
    const token = getCookie('token');
    request({
      url: `http://45.137.148.94/v1/calendar?type=day&date=${date
        .toISOString()
        .substring(0, 10)
        .split('-')
        .reverse()
        .join('-')}`,
      headers: {
        Authorization: `Bearer ${token}`,
      },
    })
      .then(translateAppointments)
      .then(setData);

    request({
      url: `http://45.137.148.94/v1/cabinet`,
      headers: {
        Authorization: `Bearer ${token}`,
      },
    })
      .then((cabinets) =>
        setResources([
          {
            fieldName: 'cabinetId',
            title: 'Location',
            instances: cabinets.map((cab) => ({
              ...cab,
              text: cab.title,
              color: cab.colorCode,
            })),
          },
        ])
      )
      .then(() => setLoading(false));

    request({
      url: `http://45.137.148.94/v1/schedule/general`,
      headers: {
        Authorization: `Bearer ${token}`,
      },
    })
      .then((schedule) => {
        const weekKey = weekDays[date.getDay()];
        setDayTime(schedule[weekKey]);
      })
      .then(() => setLoading(false));
  }, [date]);

  if (loading) {
    return null;
  }

  return (
    <Grid className={classes.container}>
      <Scheduler
        data={
          selectedPerson !== 'all'
            ? data.filter((app) => `${app.doctorId}` === `${selectedPerson}`)
            : data
        }
      >
        <ViewState
          defaultCurrentDate="2020-11-29"
          currentDate={date.toISOString().substring(0, 10)}
        />
        <GroupingState grouping={grouping} />

        <DayView startDayHour={dayTime.from} endDayHour={dayTime.to} cellDuration={60} />
        <Appointments appointmentContentComponent={Appointment} />
        <Resources data={resources} mainResourceName="cabinetId" />

        <IntegratedGrouping />
        <GroupingPanel />
      </Scheduler>
    </Grid>
  );
};
