import makeStyles from '@material-ui/core/styles/makeStyles';
import Tab from '@material-ui/core/Tab';
import Tabs from '@material-ui/core/Tabs';
import Toolbar from '@material-ui/core/Toolbar';
import Typography from '@material-ui/core/Typography';
import AppBar from '@material-ui/core/AppBar';
import React, { useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import SettingsIcon from '@material-ui/icons/Settings';
import { Avatar, Grid, IconButton, Menu, MenuItem } from '@material-ui/core';
import { Link, useLocation } from 'react-router-dom';
import { selectPageIndex } from '../../reducers/mainPageReducer';
import {
  selectIsUserAuth,
  selectUserFirstName,
  selectUserLastName,
  selectUserPhotoUrl,
  selectUserRole,
} from '../../reducers/userReducer';
import { RecordPatientModal } from '../RecordPatientModal';
import { request } from '../../utils/api';
import { getCookie } from '../../utils/cookies';

const useStyles = makeStyles((theme) => ({
  appBar: {
    backgroundColor: '#434F8A',
    boxShadow: 'none',
    border: '1px solid #707070',
  },
  tabs: {
    marginLeft: theme.spacing(2),
    marginRight: theme.spacing(2),
    '& .MuiTabs-scroller > span': {
      backgroundColor: '#383972',
      opacity: 0.5,
      height: '100%',
    },
  },
  tab: {
    width: 'fit-content',
    minWidth: 'unset',
    '& > span': {
      width: 'fit-content',
    },
  },
  typo: {
    color: 'inherit',
    textDecoration: 'none',
    userSelect: 'none',
    marginRight: theme.spacing(2),
  },
  link: {
    color: 'inherit',
    textDecoration: 'none',
    userSelect: 'none',
  },
  empty: {
    flexGrow: 1,
  },
}));

export const NavBar = () => {
  const dispatch = useDispatch();
  const location = useLocation();
  const isAuth = useSelector(selectIsUserAuth);
  const userPhotoUrl = useSelector(selectUserPhotoUrl);
  const userFirstName = useSelector(selectUserFirstName);
  const userLastName = useSelector(selectUserLastName);
  const userRole = useSelector(selectUserRole);

  const [anchorMenuEl, setAnchorMenuEl] = useState(null);

  const classes = useStyles();

  if (!isAuth) {
    return null;
  }

  return (
    <AppBar position="relative" className={classes.appBar}>
      <Toolbar variant="regular">
        <Link to="/" className={classes.typo}>
          <Typography variant="h5" color="inherit">
            DentaLight
          </Typography>
        </Link>
        <Typography className={classes.typo} variant="h6" color="inherit">
          29.11.2020
        </Typography>
        <Typography className={classes.typo} variant="h6" color="inherit">
          16:50
        </Typography>
        {location.pathname === '/' ? <MainPageActions /> : null}
        <div className={classes.empty} />
        {userRole === 'director' ? (
          <Link to="/settings" color="inherit" className={classes.link}>
            <IconButton color="inherit">
              <SettingsIcon color="inherit" />
            </IconButton>
          </Link>
        ) : null}
        <Grid container direction="column" alignItems="flex-end" style={{ width: 'fit-content' }}>
          <Typography>{userFirstName}</Typography>
          <Typography>{userLastName}</Typography>
        </Grid>
        <div>
          <IconButton
            aria-controls="simple-menu"
            aria-haspopup="true"
            color="inherit"
            onClick={(e) => setAnchorMenuEl(e.currentTarget)}
          >
            <Avatar color="inherit" src={userPhotoUrl} />
          </IconButton>
          <Menu
            id="simple-menu"
            anchorEl={anchorMenuEl}
            keepMounted
            open={Boolean(anchorMenuEl)}
            onClose={() => setAnchorMenuEl(null)}
          >
            <MenuItem
              onClick={async () => {
                const token = getCookie('token');
                request({
                  url: `http://45.137.148.94/v1/auth/logout`,
                  method: 'POST',
                  headers: {
                    Authorization: `Bearer ${token}`,
                  },
                }).then(() => dispatch({ type: 'logout' }));
                setAnchorMenuEl(null);
              }}
            >
              Logout
            </MenuItem>
          </Menu>
        </div>
      </Toolbar>
    </AppBar>
  );
};

const MainPageActions = () => {
  const dispatch = useDispatch();
  const currentPageIndex = useSelector(selectPageIndex);
  const classes = useStyles();

  return (
    <>
      <Tabs
        style={{ display: 'none' }}
        className={classes.tabs}
        value={currentPageIndex}
        onChange={(_, value) => dispatch({ type: 'set_page', payload: { page: value } })}
      >
        <Tab className={classes.tab} disableRipple label="Ordinace" />
        <Tab className={classes.tab} disableRipple label="Lékaři" />
      </Tabs>
      <RecordPatientModal />
    </>
  );
};
