import {
  Dialog,
  DialogContent,
  DialogTitle,
  FormControl,
  FormControlLabel,
  FormLabel,
  Grid,
  makeStyles,
  MenuItem,
  Radio,
  RadioGroup,
  Snackbar,
  TextField,
  Typography,
} from '@material-ui/core';
import Button from '@material-ui/core/Button';
import Alert from '@material-ui/lab/Alert';
import React, { useEffect, useState } from 'react';
import { request } from '../../utils/api';
import { getCookie } from '../../utils/cookies';

const useStyles = makeStyles((theme) => ({
  firstBlock: {
    marginRight: theme.spacing(3),
    width: 300,
  },
  secondBlock: {
    width: 300,
  },
  dialog: {
    '& .MuiDialog-paperWidthSm': {
      maxWidth: 'none',
    },
  },
  dialogTitle: {
    color: '#ffffff',
    background: '#434F8A 0% 0% no-repeat padding-box',
    border: '1px solid #707070',
  },
  dialogContent: {
    background:
      'transparent linear-gradient(180deg, #36346C 0%, #4D619E 100%) 0% 0% no-repeat padding-box',
  },
  inputInRow: {
    marginRight: theme.spacing(2),
  },
  multilineInput: {
    minHeight: theme.spacing(26),
  },
  submitButton: {
    marginTop: 'auto',
    marginBottom: theme.spacing(1),
  },
  formLabel: {
    color: '#ffffff !important',
    marginBottom: theme.spacing(1),
  },
  radioLabel: {
    color: '#ffffff !important',
    '& > span:hover': {
      backgroundColor: 'none',
    },
  },
  // dialogTitle: {
  //   display: 'flex',
  // }
}));

export const DentaLightInput = (props) => {
  return (
    <TextField
      rows={4}
      margin="dense"
      variant="filled"
      fullWidth
      // eslint-disable-next-line react/destructuring-assignment
      InputProps={{ disableUnderline: true, ...(props?.InputProps || {}) }}
      // eslint-disable-next-line react/jsx-props-no-spreading
      {...props}
    />
  );
};

export const RecordPatientModal = () => {
  const token = getCookie('token');
  const classes = useStyles();
  const [open, setOpen] = useState(false);
  const [client, setClient] = useState({});
  const [appointment, setAppointment] = useState({});
  const [doctors, setDoctors] = useState([]);
  const [cabinets, setCabinets] = useState([]);
  const [isExistClient, setIsExistClient] = useState(false);
  const [errorMessage, setErrorMessage] = useState('');

  useEffect(() => {
    if (!open) {
      setClient({});
      setAppointment({});
      setIsExistClient(false);
      setErrorMessage('');
    }
  }, [open]);

  useEffect(() => {
    request({
      url: 'http://45.137.148.94/v1/user/doctors',
      headers: { Authorization: `Bearer ${token}` },
    }).then(setDoctors);

    request({
      url: 'http://45.137.148.94/v1/cabinet',
      headers: { Authorization: `Bearer ${token}` },
    }).then(setCabinets);
  }, [token]);

  const onCheckClient = () => {
    request({
      url: `http://45.137.148.94/v1/client?insuranceNumber=${client.insuranceNumber}`,
      headers: { Authorization: `Bearer ${token}` },
    })
      .then((foundClient) => {
        setClient({ ...client, ...foundClient });
        setIsExistClient(true);
      })
      .catch((res) => {
        if (res.status === 404) {
          setIsExistClient(false);
          setErrorMessage('Not found');
        }
      });
  };

  const createAppointment = () => {
    const visitDate = appointment.visitDate?.split('-').reverse().join('-');
    const birthDate = client.birthDate?.split('-').reverse().join('-');
    const formattedAppointment = { ...appointment, visitDate };
    const formattedClient = { ...client, birthDate };
    if (!isExistClient) {
      delete formattedClient.id;
    }
    request({
      url: 'http://45.137.148.94/v1/appointment',
      method: 'POST',
      body: { appointment: formattedAppointment, client: formattedClient },
      headers: { Authorization: `Bearer ${token}` },
    }).then(() => setOpen(false));
  };

  return (
    <>
      <Button variant="contained" onClick={() => setOpen(true)}>
        Objednat pacienta
      </Button>
      <Dialog className={classes.dialog} open={open} onClose={() => setOpen(false)}>
        <DialogTitle className={classes.dialogTitle}>
          <Grid container direction="row" justify="space-around" alignItems="center">
            <Typography variant="h5">Osobní údaje pacienta</Typography>
            <Typography variant="h5">Objednat pacienta</Typography>
          </Grid>
        </DialogTitle>
        <DialogContent className={classes.dialogContent}>
          <Grid container direction="row" wrap="nowrap">
            <Grid container direction="column" className={classes.firstBlock}>
              <DentaLightInput
                value={client.firstName}
                onChange={({ target }) => setClient({ ...client, firstName: target.value })}
                label="Jméno"
              />
              <DentaLightInput
                value={client.lastName}
                onChange={({ target }) => setClient({ ...client, lastName: target.value })}
                label="Příjmení"
              />
              <DentaLightInput
                value={client.birthDate}
                onChange={({ target }) => setClient({ ...client, birthDate: target.value })}
                InputLabelProps={{ shrink: true }}
                type="date"
                label="Datum narození"
              />
              <DentaLightInput
                value={client.birthNumber}
                onChange={({ target }) => setClient({ ...client, birthNumber: target.value })}
                label="Rodné číslo"
              />
              <DentaLightInput
                value={client.insuranceNumber}
                onChange={({ target }) => setClient({ ...client, insuranceNumber: target.value })}
                label="Číslo pojištění"
              />
              <Button
                fullWidth
                className={classes.submitButton}
                variant="contained"
                onClick={onCheckClient}
              >
                Hledat
              </Button>
              <DentaLightInput
                value={client.street}
                onChange={({ target }) => setClient({ ...client, street: target.value })}
                label="Ulice"
              />
              <Grid container direction="row" wrap="nowrap">
                <DentaLightInput
                  value={client.city}
                  onChange={({ target }) => setClient({ ...client, city: target.value })}
                  className={classes.inputInRow}
                  label="Město"
                />
                <DentaLightInput
                  value={client.postcode}
                  onChange={({ target }) => setClient({ ...client, postcode: target.value })}
                  label="PSČ"
                />
              </Grid>
              <DentaLightInput
                value={client.phone}
                onChange={({ target }) => setClient({ ...client, phone: target.value })}
                label="Telefonní čislo"
              />
              <DentaLightInput
                label="E-mail"
                value={client.email}
                onChange={({ target }) => setClient({ ...client, email: target.value })}
              />
              <DentaLightInput
                value={client.allergies}
                onChange={({ target }) => setClient({ ...client, allergies: target.value })}
                label="Alergie"
                multiline
              />
              <FormControl margin="dense">
                <FormLabel className={classes.formLabel}>Způsob oznámeni</FormLabel>
                <RadioGroup
                  value={client.notificationType}
                  onChange={({ target }) =>
                    setClient({ ...client, notificationType: target.value })
                  }
                  defaultValue="phone"
                >
                  <Grid container direction="row" wrap="nowrap">
                    <FormControlLabel
                      className={classes.radioLabel}
                      value="phone"
                      control={<Radio disableRipple color="primary" />}
                      label="Telefonický"
                    />
                    <FormControlLabel
                      className={classes.radioLabel}
                      value="sms"
                      control={<Radio disableRipple color="primary" />}
                      label="SMS"
                    />
                    <FormControlLabel
                      className={classes.radioLabel}
                      value="email"
                      control={<Radio disableRipple color="primary" />}
                      label="Mailem"
                    />
                  </Grid>
                </RadioGroup>
              </FormControl>
            </Grid>
            <Grid container direction="column" className={classes.secondBlock}>
              <DentaLightInput
                required
                select
                label="Lékař"
                value={appointment.doctorId}
                onChange={({ target }) =>
                  setAppointment({ ...appointment, doctorId: target.value })
                }
              >
                {doctors.map((doctor) => (
                  <MenuItem key={doctor.id} value={doctor.id}>
                    {doctor.firstName}
                  </MenuItem>
                ))}
              </DentaLightInput>
              <DentaLightInput
                value={appointment.visitDate}
                onChange={({ target }) =>
                  setAppointment({ ...appointment, visitDate: target.value })
                }
                type="date"
                InputLabelProps={{ shrink: true }}
                label="Datum zchůzky"
              />
              <FormControl margin="normal">
                <FormLabel className={classes.formLabel}>Čas zchůzky</FormLabel>
                <Grid container direction="row" wrap="nowrap" justify="space-between">
                  <DentaLightInput
                    value={appointment.visitTimeFrom}
                    onChange={({ target }) =>
                      setAppointment({ ...appointment, visitTimeFrom: target.value })
                    }
                    label="od"
                    margin="none"
                    className={classes.inputInRow}
                    type="time"
                    InputLabelProps={{ shrink: true }}
                    inputProps={{ step: 900 }}
                  />
                  <DentaLightInput
                    value={appointment.visitTimeTo}
                    onChange={({ target }) =>
                      setAppointment({ ...appointment, visitTimeTo: target.value })
                    }
                    label="do"
                    margin="none"
                    type="time"
                    InputLabelProps={{ shrink: true }}
                    inputProps={{ step: 900 }}
                  />
                </Grid>
              </FormControl>
              <DentaLightInput
                select
                label="Ordinace"
                value={appointment.cabinetId}
                onChange={({ target }) =>
                  setAppointment({ ...appointment, cabinetId: target.value })
                }
              >
                {cabinets.map((cabinet) => (
                  <MenuItem key={cabinet.id} value={cabinet.id}>
                    {cabinet.title}
                  </MenuItem>
                ))}
              </DentaLightInput>
              <DentaLightInput
                label="Stížností"
                multiline
                value={appointment.complaint}
                onChange={({ target }) =>
                  setAppointment({ ...appointment, complaint: target.value })
                }
              />
              <DentaLightInput
                label="Diagnóza"
                value={appointment.diagnosis}
                onChange={({ target }) =>
                  setAppointment({ ...appointment, diagnosis: target.value })
                }
              />
              <DentaLightInput
                label="Komentář"
                multiline
                value={appointment.comment}
                onChange={({ target }) => setAppointment({ ...appointment, comment: target.value })}
              />
              <Button
                className={classes.submitButton}
                variant="contained"
                onClick={createAppointment}
              >
                Objednat zchůzku
              </Button>
            </Grid>
          </Grid>
        </DialogContent>
        <Snackbar open={errorMessage} autoHideDuration={6000} onClose={() => setErrorMessage('')}>
          <Alert onClose={() => setErrorMessage('')} severity="error">
            {errorMessage}
          </Alert>
        </Snackbar>
      </Dialog>
    </>
  );
};
