import Container from '@material-ui/core/Container';
import makeStyles from '@material-ui/core/styles/makeStyles';
import React from 'react';
import { useDispatch } from 'react-redux';
import { request } from '../../utils/api';
import { deleteCookie, setCookie } from '../../utils/cookies';
import { LoginForm } from './components/LoginForm';

const useStyles = makeStyles(() => ({
  container: {
    height: '100%',
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
  },
}));

const LoginPage = () => {
  const dispatch = useDispatch();
  const classes = useStyles();

  /**
   * обработчик формы логина
   * по нажатию на enter или по клику на кнопку
   * вызывается с параметрами email и password данная функция которая отправляет
   * на сервер поля email и password
   */
  const onSubmit = (email, password) => {
    request({
      url: 'http://45.137.148.94/v1/auth/signin',
      method: 'POST',
      body: {
        email,
        password,
      },
    })
      /**
       * после успешного запроса на логин,
       * сервер возвращает данные текущего пользователя
       * и его токен(который затем используется для дальнейших запросов).
       * Данные пользователя сохраняются в локальном хранилище (redux store)
       */
      .then(({ token, user }) => {
        setCookie('token', token);
        dispatch({ type: 'login', payload: { user } });
      })
      .catch((e) => {
        /** в случае неуспешного запроса, удаляется из cookies токен(на всякий случай) */
        deleteCookie('token');
        console.log(e);
      });
  };

  return (
    <Container className={classes.container}>
      <LoginForm onSubmit={onSubmit} />
    </Container>
  );
};

export default LoginPage;
