import { Container, Grid, makeStyles } from '@material-ui/core';
import { DatePicker } from '@material-ui/pickers';
import React, { useState } from 'react';
import { DayScheduler } from '../../components/DayScheduler';
import { DoctorList } from './components/DoctorList';

const useStyles = makeStyles(() => ({
  container: {
    maxWidth: 'none',
    padding: 0,
  },
  datePickerContainer: {
    color: '#ffffff !important',
    width: 'fit-content',
    '& *': {
      color: '#ffffff',
    },
    '& .MuiPickersCalendarHeader-iconButton': {
      backgroundColor: 'transparent',
    },
    '& .MuiPickersStaticWrapper-staticWrapperRoot': {
      backgroundColor: 'transparent',
    },
    '& .MuiPickersToolbar-toolbar': {
      backgroundColor: 'transparent',
    },
    '& .MuiPickersBasePicker-pickerView': {
      backgroundColor: 'transparent',
    },
  },
}));

const MainPage = () => {
  const classes = useStyles();
  const [currentDate, setCurrentDate] = useState(new Date());
  const [selectedPerson, setSelectedPerson] = useState('all');

  return (
    <Container className={classes.container}>
      <Grid container direction="row" wrap="nowrap">
        <Grid
          container
          item
          direction="column"
          wrap="nowrap"
          className={classes.datePickerContainer}
        >
          <DatePicker
            ToolbarComponent={() => null}
            autoOk
            size="small"
            variant="static"
            value={currentDate}
            onChange={setCurrentDate}
            openTo="date"
          />
          <DoctorList value={selectedPerson} onSelect={setSelectedPerson} />
        </Grid>
        <Grid
          style={{ height: 'calc(100vh - 70px)' }}
          container
          item
          direction="column"
          wrap="nowrap"
          xs="auto"
        >
          <DayScheduler date={currentDate} selectedPerson={selectedPerson} />
        </Grid>
      </Grid>
    </Container>
  );
};

export default MainPage;
