import {
  Grid,
  IconButton,
  List,
  ListItem,
  ListItemIcon,
  ListItemSecondaryAction,
  ListItemText,
  makeStyles,
  Typography,
} from '@material-ui/core';
import { AddCircle, Brightness1, Delete as DeleteIcon } from '@material-ui/icons';
import React, { useEffect, useState } from 'react';
import randomColor from 'randomcolor';
import { request } from '../../../utils/api';
import { getCookie } from '../../../utils/cookies';

const useStyles = makeStyles((theme) => ({
  container: {
    width: 'fit-content',
    color: '#ffffff',
    marginTop: theme.spacing(5),
  },
  list: {},
}));

export const EditCabinet = ({ onError }) => {
  const token = getCookie('token');
  const classes = useStyles();
  const [cabinets, setCabinets] = useState([]);
  const [toggleFetch, setToggleFetch] = useState(true);

  useEffect(() => {
    request({
      url: 'http://45.137.148.94/v1/cabinet',
      headers: {
        Authorization: `Bearer ${token}`,
      },
    })
      .then(setCabinets)
      .catch((e) => onError(e?.statusText));
  }, [token, toggleFetch, onError]);

  const onDeleteCabinet = async (id) => {
    await request({
      url: `http://45.137.148.94/v1/cabinet/${id}`,
      method: 'DELETE',
      headers: {
        Authorization: `Bearer ${token}`,
      },
    }).catch((e) => onError(e?.statusText));
    setToggleFetch(!toggleFetch);
  };

  const onAddCabinet = async () => {
    let foundColor = '';
    while (!foundColor) {
      const newColor = randomColor();
      foundColor = cabinets.find(({ colorCode }) => colorCode.match(newColor)) ? '' : newColor;
    }
    await request({
      url: 'http://45.137.148.94/v1/cabinet/',
      method: 'POST',
      body: { colorCode: foundColor, title: `Ordinace ${cabinets.length + 1}` },
      headers: {
        Authorization: `Bearer ${token}`,
      },
    }).catch((e) => onError(e?.statusText));
    setToggleFetch(!toggleFetch);
  };

  return (
    <Grid sm={4} md={3} container item direction="column" className={classes.container}>
      <Typography align="center" variant="h5" color="inherit">
        Ordinace
      </Typography>
      <List className={classes.list}>
        {cabinets.map((cabinet) => (
          <ListItem button key={cabinet.id}>
            <ListItemIcon>
              <Brightness1 htmlColor={cabinet.colorCode} />
            </ListItemIcon>
            <ListItemText>{cabinet.title}</ListItemText>
            <ListItemSecondaryAction onClick={() => onDeleteCabinet(cabinet.id)}>
              <IconButton edge="end" aria-label="delete">
                <DeleteIcon color="error" />
              </IconButton>
            </ListItemSecondaryAction>
          </ListItem>
        ))}
        <ListItem button onClick={onAddCabinet}>
          <ListItemIcon>
            <AddCircle htmlColor="#ffffff" />
          </ListItemIcon>
          <ListItemText>Přidat</ListItemText>
        </ListItem>
      </List>
    </Grid>
  );
};
