import {
  Avatar,
  Button,
  Checkbox,
  Dialog,
  DialogActions,
  DialogContent,
  DialogTitle,
  FormControlLabel,
  Grid,
  IconButton,
  List,
  ListItem,
  ListItemIcon,
  ListItemSecondaryAction,
  ListItemText,
  makeStyles,
  MenuItem,
  Typography,
} from '@material-ui/core';
import { AddCircle, CalendarToday } from '@material-ui/icons';
import React, { useEffect, useState } from 'react';
import { request } from '../../../utils/api';
import { getCookie } from '../../../utils/cookies';
import { DentaLightInput } from '../../../components/RecordPatientModal';
import { initialSchedule, TimeInput, localeWeek } from './EditGeneralSchedule';

const useStyles = makeStyles((theme) => ({
  container: {
    width: 'fit-content',
    color: '#ffffff',
    marginTop: theme.spacing(5),
  },
  dialog: {
    '& .MuiDialog-paperWidthSm': {
      maxWidth: 'none',
      width: '320px',
    },
  },
  dialogTitle: {
    color: '#ffffff',
    background: '#434F8A 0% 0% no-repeat padding-box',
    border: '1px solid #707070',
  },
  dialogContent: {
    background:
      'transparent linear-gradient(180deg, #36346C 0%, #4D619E 100%) 0% 0% no-repeat padding-box',
  },
  submitButton: {
    marginTop: theme.spacing(1),
    marginBottom: theme.spacing(1),
  },
}));

const roles = [
  { title: 'Doctor', value: 'doctor' },
  { title: 'Director', value: 'director' },
  { title: 'Admin', value: 'administrator' },
];

export const EditDoctorsList = ({ onError }) => {
  const classes = useStyles();
  const [showStuffDialog, setShowStuffDialog] = useState(false);
  const [showCalendarDialog, setShowCalendarDialog] = useState(false);

  const [doctors, setDoctors] = useState([]);

  const [firstName, setFirstName] = useState();
  const [doctorId, setDoctorId] = useState();
  const [lastName, setLastName] = useState();
  const [email, setEmail] = useState();
  const [password, setPassword] = useState();
  const [selectedRole, setSelectedRole] = useState();
  const [photoUrl, setPhotoUrl] = useState();
  const [doctorSpecialization, setDoctorSpecialization] = useState();
  const [colorCode, setColorCode] = useState('#000000');
  const [isDoctor, setIsDoctor] = useState();
  const [triggerFetch, setTriggerFetch] = useState(true);

  useEffect(() => {
    const token = getCookie('token');
    request({
      url: 'http://45.137.148.94/v1/user/doctors',
      headers: {
        Authorization: `Bearer ${token}`,
      },
    })
      .then(setDoctors)
      .catch((e) => onError?.(e?.statusText));
  }, [triggerFetch, onError]);

  useEffect(() => {
    if (!showStuffDialog) {
      setFirstName();
      setLastName();
      setEmail();
      setPassword();
      setSelectedRole();
      setPhotoUrl();
      setDoctorSpecialization();
      setColorCode();
      setIsDoctor();
    }
  }, [showStuffDialog]);

  const onSelectDoctor = (userToSelect = {}) => {
    setFirstName(userToSelect.firstName);
    setLastName(userToSelect.lastName);
    setEmail(userToSelect.email);
    setPassword(userToSelect.password);
    setSelectedRole(userToSelect.role);
    setPhotoUrl(userToSelect.photoUrl);
    setDoctorSpecialization(userToSelect.doctorSpecialization);
    setColorCode(userToSelect.colorCode);
    setIsDoctor(userToSelect.isDoctor);
    setShowStuffDialog(true);
  };

  const onAddDoctor = async (e) => {
    const token = getCookie('token');
    e?.preventDefault();
    await request({
      url: 'http://45.137.148.94/v1/auth/signup',
      method: 'POST',
      body: {
        email,
        password,
        role: selectedRole,
        doctorSpecialization,
        firstName,
        lastName,
        photoUrl,
        colorCode,
        isDoctor,
      },
      headers: {
        Authorization: `Bearer ${token}`,
      },
    })
      .then(() => setShowStuffDialog(false))
      .catch((err) => onError?.(err?.statusText));
    setTriggerFetch(!triggerFetch);
  };

  const postDoctor = () => {
    return (
      <Dialog
        className={classes.dialog}
        open={showStuffDialog}
        onClose={() => setShowStuffDialog(false)}
      >
        <DialogTitle className={classes.dialogTitle}>
          <Grid container direction="row" justify="space-around" alignItems="center">
            <Typography variant="h5">Přidat</Typography>
          </Grid>
        </DialogTitle>
        <DialogContent className={classes.dialogContent}>
          <form onSubmit={onAddDoctor}>
            <Grid container direction="column" wrap="nowrap">
              <DentaLightInput
                required
                value={firstName}
                onChange={({ target }) => setFirstName(target.value)}
                label="Jméno"
              />
              <DentaLightInput
                required
                value={lastName}
                onChange={({ target }) => setLastName(target.value)}
                label="Příjmení"
              />
              <DentaLightInput
                required
                label="E-mail"
                type="email"
                value={email}
                onChange={({ target }) => setEmail(target.value)}
              />
              <DentaLightInput
                required
                label="Heslo"
                value={password}
                onChange={({ target }) => setPassword(target.value)}
              />
              <DentaLightInput
                label="Foto Url"
                type="url"
                value={photoUrl}
                onChange={({ target }) => setPhotoUrl(target.value)}
              />
              <DentaLightInput
                required
                label="Specializace"
                value={doctorSpecialization}
                onChange={({ target }) => setDoctorSpecialization(target.value)}
              />
              <DentaLightInput
                required
                select
                label="Role"
                value={selectedRole}
                onChange={({ target }) => {
                  setSelectedRole(target.value);
                  if (target.value === 'doctor') {
                    setIsDoctor(true);
                  } else if (target.value === 'administrator') {
                    setIsDoctor(false);
                  }
                }}
              >
                {roles.map((role) => (
                  <MenuItem key={role.value} value={role.value}>
                    {role.title}
                  </MenuItem>
                ))}
              </DentaLightInput>
              <DentaLightInput
                required
                type="color"
                label="Barva"
                value={colorCode}
                onChange={({ target }) => setColorCode(target.value)}
              />
              {selectedRole === 'director' ? (
                <FormControlLabel
                  checked={isDoctor}
                  onChange={({ target }) => setIsDoctor(target.checked)}
                  control={<Checkbox color="primary" name="isDoctor" />}
                  label="Doctor"
                />
              ) : null}
              <Button type="submit" className={classes.submitButton} variant="contained">
                Přidat
              </Button>
            </Grid>
          </form>
        </DialogContent>
      </Dialog>
    );
  };

  const onClickCalendar = (doctorIdToSet) => {
    setDoctorId(doctorIdToSet);
    setShowCalendarDialog(true);
  };

  return (
    <>
      <Grid sm={4} md={3} container item direction="column" className={classes.container}>
        <Typography align="center" variant="h5" color="inherit">
          Zaměstnanci
        </Typography>
        <List>
          {doctors.map((doctor) => (
            <ListItem button key={doctor.id} onClick={() => onSelectDoctor(doctor)}>
              <ListItemIcon>
                <Avatar alt={`${doctor.firstName} ${doctor.lastName}`} src={doctor.photoUrl} />
              </ListItemIcon>
              <ListItemText primary={`${doctor.firstName} ${doctor.lastName}`} />
              <ListItemSecondaryAction onClick={() => onClickCalendar(doctor.id)}>
                <IconButton edge="end" aria-label="delete">
                  <CalendarToday htmlColor="#ffffff" />
                </IconButton>
              </ListItemSecondaryAction>
            </ListItem>
          ))}
          <ListItem button onClick={() => setShowStuffDialog(true)}>
            <ListItemIcon>
              <AddCircle htmlColor="#ffffff" />
            </ListItemIcon>
            <ListItemText>Přidat</ListItemText>
          </ListItem>
        </List>
      </Grid>
      {postDoctor()}
      <ScheduleModal
        onError={onError}
        doctorId={doctorId}
        show={showCalendarDialog}
        onClose={() => setShowCalendarDialog(false)}
      />
    </>
  );
};

const ScheduleModal = ({ doctorId, show, onClose, onError }) => {
  const classes = useStyles();
  const [schedule, setSchedule] = useState(initialSchedule);

  useEffect(() => {
    if (show && doctorId) {
      const token = getCookie('token');
      request({
        url: `http://45.137.148.94/v1/schedule/${doctorId}`,
        headers: {
          Authorization: `Bearer ${token}`,
        },
      })
        .then(setSchedule)
        .catch((err) => onError(err.statusText));
    }
  }, [doctorId, onError, show]);

  const onUpdateSchedule = () => {
    const token = getCookie('token');
    request({
      url: `http://45.137.148.94/v1/schedule/${doctorId}`,
      method: 'POST',
      body: schedule,
      headers: {
        Authorization: `Bearer ${token}`,
      },
    }).catch((err) => onError(err.statusText));
  };

  return (
    <Dialog className={classes.dialog} open={show} onClose={onClose}>
      <DialogTitle className={classes.dialogTitle}>
        <Grid container direction="row" justify="space-around" alignItems="center">
          <Typography variant="h5">Pracovni doba</Typography>
        </Grid>
      </DialogTitle>
      <DialogContent className={classes.dialogContent}>
        {Object.entries(schedule).map(([key, value]) => (
          <TimeInput
            key={key}
            formLabel={localeWeek[key]}
            timeValue={value}
            onChange={(newTimeValue) => setSchedule({ ...schedule, [key]: newTimeValue })}
          />
        ))}
        {/* <FormControlLabel
          checked={isDoctor}
          onChange={({ target }) => setIsDoctor(target.checked)}
          control={<Checkbox color="primary" name="isDoctor" />}
          label="Doctor"
        /> */}
      </DialogContent>
      <DialogActions>
        <Button onClick={onUpdateSchedule}>Ulozit</Button>
      </DialogActions>
    </Dialog>
  );
};
