import {
  Button,
  FormControl,
  FormLabel,
  Grid,
  makeStyles,
  TextField,
  Typography,
} from '@material-ui/core';
import React, { useEffect, useState } from 'react';
import { request } from '../../../utils/api';
import { getCookie } from '../../../utils/cookies';

const useStyles = makeStyles((theme) => ({
  container: {
    width: 'fit-content',
    color: '#ffffff',
    marginTop: theme.spacing(5),
  },
  formLabel: {
    color: '#ffffff !important',
    marginRight: theme.spacing(2),
    width: '2ch',
  },
  inputInRow: {
    marginRight: theme.spacing(2),
  },
  saveButton: {
    marginTop: theme.spacing(2),
    width: 'fit-content',
    '& .MuiButton-label': {
      width: 'fit-content',
    },
  },
}));

export const TimeInput = ({ formLabel, timeValue = { from: '', to: '' }, onChange }) => {
  const classes = useStyles();

  const onChangeTime = (type, value) => {
    onChange({ ...timeValue, [type]: value });
  };

  return (
    <FormControl margin="normal">
      <Grid container item direction="row" alignItems="center" justify="center">
        <FormLabel className={classes.formLabel}>{formLabel}</FormLabel>
        <TextField
          value={timeValue.from}
          type="time"
          inputProps={{ step: 900 }}
          InputLabelProps={{ shrink: true }}
          // eslint-disable-next-line react/jsx-no-duplicate-props
          InputProps={{ disableUnderline: true }}
          className={classes.inputInRow}
          onChange={({ target }) => onChangeTime('from', target.value)}
        />
        <TextField
          value={timeValue.to}
          type="time"
          inputProps={{ step: 900 }}
          InputLabelProps={{ shrink: true }}
          // eslint-disable-next-line react/jsx-no-duplicate-props
          InputProps={{ disableUnderline: true }}
          onChange={({ target }) => onChangeTime('to', target.value)}
        />
      </Grid>
    </FormControl>
  );
};

export const initialSchedule = {
  monday: {
    from: '07:00',
    to: '22:00',
  },
  tuesday: {
    from: '07:00',
    to: '22:00',
  },
  wednesday: {
    from: '07:00',
    to: '22:00',
  },
  thursday: {
    from: '07:00',
    to: '22:00',
  },
  friday: {
    from: '07:00',
    to: '22:00',
  },
  saturday: {
    from: '07:00',
    to: '22:00',
  },
  sunday: {
    from: '07:00',
    to: '22:00',
  },
};

export const localeWeek = {
  monday: 'Po',
  tuesday: 'Út',
  wednesday: 'St',
  thursday: 'Čt',
  friday: 'Pá',
  saturday: 'So',
  sunday: 'Ne',
};

export const EditGeneralSchedule = ({ onError }) => {
  const classes = useStyles();
  const token = getCookie('token');
  const [schedule, setSchedule] = useState(initialSchedule);

  useEffect(() => {
    request({
      url: 'http://45.137.148.94/v1/schedule/general',
      headers: {
        Authorization: `Bearer ${token}`,
      },
    })
      .then(setSchedule)
      .catch((e) => onError(e?.statusText));
  }, [token, onError]);

  const onSaveSchedule = () => {
    request({
      url: 'http://45.137.148.94/v1/schedule/general',
      method: 'POST',
      body: schedule,
      headers: {
        Authorization: `Bearer ${token}`,
      },
    }).catch((e) => onError(e?.statusText));
  };

  return (
    <Grid sm={4} md={3} container item direction="column" className={classes.container}>
      <Typography align="center" variant="h5" color="inherit">
        Otevírací doba
      </Typography>
      {Object.entries(schedule).map(([key, value]) => (
        <TimeInput
          key={key}
          formLabel={localeWeek[key]}
          timeValue={value}
          onChange={(newTimeValue) => setSchedule({ ...schedule, [key]: newTimeValue })}
        />
      ))}
      <Grid container item direction="row" alignItems="center" justify="center">
        <Button className={classes.saveButton} variant="contained" onClick={onSaveSchedule}>
          Uložit
        </Button>
      </Grid>
    </Grid>
  );
};
