const getRequestOptions = (method = 'GET', body, extraHeaders = {}) => {
  const baseHeaders = { 'Content-Type': 'application/json' };

  const headers = {
    ...baseHeaders,
    ...extraHeaders,
  };

  return {
    method,
    headers,
    ...(body && { body: JSON.stringify(body) }),
  };
};

export async function request({ url, method, body, headers, handleSuccess, handleError }) {
  try {
    const call = await fetch(url, getRequestOptions(method, body, headers));
    if (!call.ok) {
      const { status, statusText } = call;
      const errorObject = { status, statusText };
      return Promise.reject(errorObject);
    }
    const data = await call.json();
    return handleSuccess ? handleSuccess(data) : data;
  } catch (error) {
    return handleError ? handleError(error) : Promise.reject(error);
  }
}

export function getRequestQueries(queries) {
  const keys = Object.keys(queries);
  if (keys.length === 0) return '';

  return `?${keys.map((key) => `${key}=${queries[key]}`).join('&')}`;
}
